# wxy-MySQL

#### 介绍
MySQL相关操作


#### 安装教程

1. 安装pymysql
2. 安装pip
3. 安装setuptools
4. 安装twine



#### 使用教程

1. 安装 pip install wxy_MySQL
2. 卸载 pip uninstall wxy_MySQL
3. 升级 pip install --upgrade wxy_MySQL
3. 调用 from wxy_MySQL import MySQLdb
